@@ -237,9 +237,6 @@ class GitHub2GitLab(object):
             log.info(action + " branch " + 'pull/' + pr + "/merge == " +
                      merge.hexsha)
             repo.git.update_ref('refs/heads/pull/' + pr + '/merge', merge)
-            log.info(action + " branch " + 'pull/' + pr + "/head == " +
-                     head.commit.hexsha)
-            repo.git.update_ref('refs/heads/pull/' + pr + '/head', head.commit)
 
     def add_key(self):
         "Add ssh key to gitlab if necessary"
