@@ -18,16 +18,19 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see `<http://www.gnu.org/licenses/>`.
 #
-import os
-import sys
+from github2gitlab import main
 import json
 import logging
+import os
 import requests
 import shutil
+import sys
 import tempfile
-from github2gitlab import main
 
-class Integration:
+log = logging.getLogger('github2gitlab')
+
+
+class Integration(object):
 
     def __init__(self, argv):
         self.g = main.GitHub2GitLab.factory(argv)
@@ -37,17 +40,18 @@ class Integration:
             os.chdir(d)
             self.reset_github()
 
-            logging.debug("---------- initial sync")
+            log.debug("---------- initial sync")
             self.create_pull_request()
             self.g.run()
             self.verify_create_pull_request()
 
-            logging.debug("---------- merged pull (not sync'ed when open, sync'ed after it was merged)")
+            log.debug("---------- merged pull (not sync'ed when open, "
+                      "sync'ed after it was merged)")
             number = self.create_pull_request_and_merge()
             self.g.run()
             self.verify_create_pull_request_and_merge(number)
 
-            logging.debug("---------- closed pull")
+            log.debug("---------- closed pull")
             self.close_pull_1()
             self.rebase_branches()
             self.modify_master()
@@ -56,12 +60,13 @@ class Integration:
             self.g.run()
             self.verify_closed_pull()
 
-            logging.debug("---------- deleted branch")
+            log.debug("---------- deleted branch")
             self.add_deleted_branch()
             self.g.run()
             self.verify_deleted_branch()
 
-            logging.debug("---------- merged pull (sync'ed when open, merged, then sync'ed after merge)")
+            log.debug("---------- merged pull (sync'ed when open, merged, "
+                      "then sync'ed after merge)")
             self.merge_pull_4()
             self.g.run()
             self.verify_merge_pull()
@@ -73,7 +78,7 @@ class Integration:
         g = self.g.github
         url = g['url'] + "/repos/" + g['repo'] + "/pulls"
         query = {'access_token': g['token']}
-        for i in (1,2,3,4):
+        for i in (1, 2, 3, 4):
             data = {
                 'title': u'title branch é {i}'.format(i=i),
                 'head': 'branch' + str(i),
@@ -106,11 +111,12 @@ git push origin master
 
     def verify_create_pull_request(self):
         g = self.g.gitlab
-        merges = self.g.get(g['url'] + "/projects/" + g['repo'] + "/merge_requests",
+        merges = self.g.get(g['url'] + "/projects/" + g['repo'] +
+                            "/merge_requests",
                             {'private_token': g['token'],
                              'state': 'open'},
                             cache=False)
-        logging.debug("merges " + str(merges))
+        log.debug("merges " + str(merges))
         assert len(merges) == 4
         for merge in merges:
             assert 'pull/' in merge['source_branch']
@@ -134,20 +140,22 @@ git push origin master
         url = g['url'] + "/repos/" + g['repo'] + "/pulls/" + number + "/merge"
         data = {'commit_message': 'COMMIT MESSAGE'}
         r = requests.put(url, params=query, data=json.dumps(data))
-        logging.debug("merge output " + r.text)
+        log.debug("merge output for PR " + str(number) + ": " + r.text)
         r.raise_for_status()
         return number
 
     def verify_create_pull_request_and_merge(self, number):
         g = self.g.gitlab
-        merges = self.g.get(g['url'] + "/projects/" + g['repo'] + "/merge_requests",
+        merges = self.g.get(g['url'] + "/projects/" + g['repo'] +
+                            "/merge_requests",
                             {'private_token': g['token'],
                              'state': 'open'},
                             cache=False)
-        logging.debug("merges " + str(merges))
-        merge = filter(lambda merge: merge['source_branch'] == 'pull/' + number + '/head',
+        log.debug("merges " + str(merges))
+        merge = filter(lambda merge: (merge['source_branch'] == 'pull/' +
+                                      number + '/head'),
                        merges)
-        logging.debug("merge " + str(merge))
+        log.debug("merge " + str(merge))
         assert 'closed' == merge[0]['state']
         assert main.GitHub2GitLab.TAG_MERGED in merge[0]['description']
 
@@ -156,18 +164,20 @@ git push origin master
         url = g['url'] + "/repos/" + g['repo'] + "/pulls/1"
         query = {'access_token': g['token']}
         data = {'state': 'closed'}
-        r = requests.patch(url, params=query, data=json.dumps(data))
-        
+        requests.patch(url, params=query, data=json.dumps(data))
+
     def verify_closed_pull(self):
         g = self.g.gitlab
-        merges = self.g.get(g['url'] + "/projects/" + g['repo'] + "/merge_requests",
+        merges = self.g.get(g['url'] + "/projects/" + g['repo'] +
+                            "/merge_requests",
                             {'private_token': g['token'],
                              'state': 'all'},
                             cache=False)
-        logging.debug("merges " + str(merges))
+        log.debug("merges " + str(merges))
         assert len(merges) == 5
         for merge in merges:
-            logging.debug("source_branch " + merge['source_branch'] + " state " + merge['state'])
+            log.debug("source_branch " + merge['source_branch'] +
+                      " state " + merge['state'])
             if merge['source_branch'] in ('pull/1/head', 'pull/5/head'):
                 assert merge['state'] == 'closed'
             else:
@@ -191,11 +201,12 @@ git push origin master
 
     def verify_deleted_branch(self):
         g = self.g.gitlab
-        merges = self.g.get(g['url'] + "/projects/" + g['repo'] + "/merge_requests",
+        merges = self.g.get(g['url'] + "/projects/" + g['repo'] +
+                            "/merge_requests",
                             {'private_token': g['token'],
                              'state': 'all'},
                             cache=False)
-        logging.debug("merges " + str(merges))
+        log.debug("merges " + str(merges))
         assert len(merges) == 5
 
     def merge_pull_4(self):
@@ -204,19 +215,22 @@ git push origin master
         query = {'access_token': g['token']}
         data = {'commit_message': 'COMMIT MESSAGE'}
         r = requests.put(url, params=query, data=json.dumps(data))
-        logging.debug("merge output " + r.text)
+        log.debug("merge output " + r.text)
         r.raise_for_status()
-        
+
     def verify_merge_pull(self):
         g = self.g.gitlab
-        merges = self.g.get(g['url'] + "/projects/" + g['repo'] + "/merge_requests",
+        merges = self.g.get(g['url'] + "/projects/" + g['repo'] +
+                            "/merge_requests",
                             {'private_token': g['token'],
                              'state': 'all'},
                             cache=False)
-        logging.debug("merges " + str(merges))
+        log.debug("merges " + str(merges))
         assert len(merges) == 5
         for merge in merges:
-            if merge['source_branch'] in ('pull/1/head', 'pull/3/head', 'pull/5/head'):
+            if merge['source_branch'] in ('pull/1/head',
+                                          'pull/3/head',
+                                          'pull/5/head'):
                 assert merge['state'] == 'closed'
             elif merge['source_branch'] == 'pull/4/head':
                 assert merge['state'] == 'merged'
@@ -228,15 +242,17 @@ git push origin master
         url = g['url'] + "/projects/" + g['repo']
         query = {'private_token': g['token']}
         assert requests.delete(url, params=query).status_code in (200, 404)
-    
+
     def reset_github(self):
         g = self.g.github
-        url = g['url'] + "/repos/" + g['repo'] 
+        url = g['url'] + "/repos/" + g['repo']
         query = {'access_token': g['token']}
         assert requests.delete(url, params=query).status_code in (204, 404)
         url = g['url'] + "/user/repos"
         data = {'name': g['repo'].split('/')[1]}
-        requests.post(url, params=query, data=json.dumps(data)).raise_for_status()
+        requests.post(url,
+                      params=query,
+                      data=json.dumps(data)).raise_for_status()
         self.g.sh("""
 echo "# testrepo" >> README.md
 git init
@@ -247,10 +263,10 @@ git push -u origin master
 for i in $(seq 1 6) ; do
         touch file$i.txt
         git add file$i.txt
-        git commit -m "commit $i" 
+        git commit -m "commit $i"
         git push origin master:branch$i
         git reset --hard origin/master
 done
         """.format(repo=g['repo']))
-    
+
 Integration(sys.argv[1:])
